@@ -388,11 +388,11 @@ class TrackSegmentFinderHourglas:
                         layer_segments[segment_id,4,13] = 1
                         layer_segments[segment_id,4,14] = 1
                         layer_segments[segment_id,4,15] = 1
-                        layer_segments[segment_id+1 % layer_in.n_segs,4,0] = 1
+                        layer_segments[(segment_id+1) % layer_in.n_segs,4,0] = 1
                         layer_segments[segment_id,3,13] = 1
                         layer_segments[segment_id,3,14] = 1
                         layer_segments[segment_id,3,15] = 1
-                        layer_segments[segment_id+1 % layer_in.n_segs,3,0] = 1
+                        layer_segments[(segment_id+1) % layer_in.n_segs,3,0] = 1
                         layer_segments[segment_id,2,13] = 1
                         layer_segments[segment_id,2,14] = 1
                         layer_segments[segment_id,2,15] = 1
@@ -407,13 +407,13 @@ class TrackSegmentFinderHourglas:
                         layer_segments[segment_id+1 % layer_in.n_segs,4,1] = 1
                         layer_segments[segment_id,3,14] = 1
                         layer_segments[segment_id,3,15] = 1
-                        layer_segments[segment_id+1 % layer_in.n_segs,3,0] = 1
-                        layer_segments[segment_id+1 % layer_in.n_segs,3,1] = 1
+                        layer_segments[(segment_id+1) % layer_in.n_segs,3,0] = 1
+                        layer_segments[(segment_id+1) % layer_in.n_segs,3,1] = 1
                         layer_segments[segment_id,2,14] = 1
                         layer_segments[segment_id,2,15] = 1
-                        layer_segments[segment_id+1 % layer_in.n_segs,2,0] = 1
+                        layer_segments[(segment_id+1) % layer_in.n_segs,2,0] = 1
                         layer_segments[segment_id,1,15] = 1
-                        layer_segments[segment_id+1 % layer_in.n_segs,1,0] = 1
+                        layer_segments[(segment_id+1) % layer_in.n_segs,1,0] = 1
                         layer_segments[segment_id,0,15] = 1
                     else:
                         layer_segments[segment_id,4,j-2] = 1
@@ -456,13 +456,13 @@ class TrackSegmentFinderHourglas:
                         elif(j==15):
                             layer_segments[segment_id,4,14] = 1
                             layer_segments[segment_id,4,15] = 1
-                            layer_segments[segment_id+1 % layer_in.n_segs,4,0] = 1
+                            layer_segments[(segment_id+1) % layer_in.n_segs,4,0] = 1
                             layer_segments[segment_id,3,14] = 1
                             layer_segments[segment_id,3,15] = 1
                             layer_segments[segment_id,2,15] = 1
                             layer_segments[segment_id,1,14] = 1
                             layer_segments[segment_id,1,15] = 1
-                            layer_segments[segment_id+1 % layer_in.n_segs,0,0] = 1
+                            layer_segments[(segment_id+1) % layer_in.n_segs,0,0] = 1
                             layer_segments[segment_id,0,14] = 1
                             layer_segments[segment_id,0,15] = 1
                         else:
